@@ -48,7 +48,7 @@ class OrbitProtocol(Protocol):
     def event(self, recipients, data, jscript=True):
         self.id+=1
         if jscript:
-            data = makejson(data)
+            data = str(makejson(data))
         d = defer.Deferred()
         self.requests[self.id] = OrbitRequest(self.id, d, recipients, data)
         self.transport.write(self.requests[self.id].render())
